==> nodejs_interop-0.4.0.tar.gz: lib/src/node/stream/writable.dart <==
part of nodejs_interop.node.stream;

/// A writable stream is an abstraction for a destination to which data is written.
@JS(r'$stream.Writable')
class Writable<T> extends EventEmitter {

  /// Creates a new writable stream.
  external Writable([WritableOptions options]);

  /// Forces all written data to be buffered in memory.
  /// The buffered data will be flushed when either the [uncork] or [end] methods are called.
  external void cork();

  /// Destroys the stream, and emits the passed [error]. After this call, the writable stream has ended.
  external Writable destroy([JSError error]);

  /// Signals that no more data will be written to the [Writable].
  ///
  /// The optional [chunk] and `encoding` arguments allow one final additional chunk of data to be written immediately before closing the stream.
  /// For streams not operating in object mode, [chunk] must be a string, `Buffer` or `Uint8List`.
  /// For object mode streams, [chunk] may be any value other than `null`.
  ///
  /// If provided, the optional [callback] function is attached as a listener for the `finish` event.
  external void end([T chunk, encodingOrCallback, void callback()]);

  /// Sets the default [encoding] for this [Writable] stream.
  external Writable setDefaultEncoding(String encoding);

  /// Flushes all data buffered since [cork] was called.
  external void uncork();

  /// Writes some data to the stream, and calls the supplied [callback] once the data has been fully handled.
  ///
  /// If an error occurs, the callback may or may not be called with the error as its first argument.
  /// To reliably detect write errors, add a listener for the `error` event.
  ///
  /// The return value is `true` if the internal buffer is less than the [WritableOptions.highWaterMark] configured
  /// when the stream was created after admitting [chunk]. If `false` is returned, further attempts to write data
  /// to the stream should stop until the `drain` event is emitted.
  external bool write(T chunk, [encodingOrCallback, CompletionCallback0 callback]);
}

/// Options passed to writable streams.
@JS()
@anonymous
class WritableOptions {

  /// Creates a new path object.
  external factory WritableOptions({
    bool decodeStrings = true,
    Function destroy,
    int highWaterMark,
    bool objectMode = false,
    Function write,
    Function writev
  });

  /// Value indicating whether to decode strings into `Buffer` before passing them to [Writable.write].
  external bool get decodeStrings;

  /// Implementation for the `_destroy()` method.
  external Function get destroy;

  /// Buffer level when [Writable.write] starts returning `false`. Defaults to `16384` (16kb), or `16` for streams in object mode.
  external int get highWaterMark;

  /// Value indicating whether the stream operates in object mode.
  external bool get objectMode;

  /// Implementation for the `_write()` method.
  external Function get write;

  /// Implementation for the `_writev()` method.
  external Function get writev;
}

==> nodejs_interop-0.5.0.tar.gz: lib/src/node/stream/writable.dart <==
part of nodejs_interop.node.stream;

/// A writable stream is an abstraction for a destination to which data is written.
@JS(r'$stream.Writable')
class Writable<T> extends EventEmitter {

  /// Creates a new writable stream.
  external Writable([WritableOptions options]);

  /// Forces all written data to be buffered in memory.
  /// The buffered data will be flushed when either the [uncork] or [end] methods are called.
  external void cork();

  /// Destroys this stream, and emits the passed [error].
  /// After this call, the stream will release any internal resources.
  external Writable<T> destroy([JSError error]);

  /// Signals that no more data will be written to the [Writable].
  ///
  /// The optional [chunk] and `encoding` arguments allow one final additional chunk of data to be written immediately before closing the stream.
  /// For streams not operating in object mode, [chunk] must be a string, `Buffer` or `Uint8List`.
  /// For object mode streams, [chunk] may be any value other than `null`.
  ///
  /// If provided, the optional [callback] function is attached as a listener for the `finish` event.
  external void end([T chunk, encodingOrCallback, void callback()]);

  /// Sets the default [encoding] for this [Writable] stream.
  external Writable<T> setDefaultEncoding(String encoding);

  /// Flushes all data buffered since [cork] was called.
  external void uncork();

  /// Writes some data to the stream, and calls the supplied [callback] once the data has been fully handled.
  ///
  /// If an error occurs, the callback may or may not be called with the error as its first argument.
  /// To reliably detect write errors, add a listener for the `error` event.
  ///
  /// The return value is `true` if the internal buffer is less than the [WritableOptions.highWaterMark] configured
  /// when the stream was created after admitting [chunk]. If `false` is returned, further attempts to write data
  /// to the stream should stop until the `drain` event is emitted.
  external bool write(T chunk, [encodingOrCallback, CompletionCallback0 callback]);
}

/// Options passed to writable streams.
@JS()
@anonymous
class WritableOptions {

  /// Creates a new path object.
  external factory WritableOptions({
    bool decodeStrings = true,
    Function destroy,
    int highWaterMark,
    bool objectMode = false,
    Function write,
    Function writev
  });

  /// Value indicating whether to decode strings into `Buffer` before passing them to [Writable.write].
  external bool get decodeStrings;

  /// Implementation for the `_destroy()` method.
  external Function get destroy;

  /// Buffer level when [Writable.write] starts returning `false`.
  /// Defaults to `16384` (16kb), or `16` for streams in object mode.
  external int get highWaterMark;

  /// Value indicating whether the stream operates in object mode.
  external bool get objectMode;

  /// Implementation for the `_write()` method.
  external Function get write;

  /// Implementation for the `_writev()` method.
  external Function get writev;
}
